<?php
/**
 * Easy Digital Downloads Compatibility File.
 *
 * @link https://easydigitaldownloads.com/
 *
 * @package RT_Health
 */

// If plugin - 'Easy_Digital_Downloads' not exist then return.
if ( ! class_exists( 'Easy_Digital_Downloads' ) ) {
	return;
}

/**
 * Easy Digital Downloads Compatibility
 */
if ( ! class_exists( 'RT_Health_Edd' ) ) :

	/**
	 * Easy Digital Downloads Compatibility
	 *
	 * @since 1.0.0
	 */
	class RT_Health_Edd {

		/**
		 * Member Variable
		 *
		 * @var object instance
		 */
		private static $instance;

		/**
		 * Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Constructor
		 */
		public function __construct() {

			// Include helper functions
			require_once trailingslashit( get_template_directory() ) . '/inc/compatibility/edd/edd-helpers.php';

			// Register EDD sidebar
			add_action( 'widgets_init', array( $this, 'register_edd_sidebar' ) );

			// Replace Edd Store Sidebars.
			add_filter( 'rt_health_get_sidebar', array( $this, 'display_edd_sidebar' ) );


		}
		/**
		 * Register new EDD sidebar.
		 *
		 * @since 1.0.0
		 */
		public static function register_edd_sidebar() {

			// Register new edd single page widget area
			register_sidebar( array(
				'name'          => esc_html__( 'EDD Sidebar', 'rt-health' ),
				'id'            => 'edd-sidebar',
				'description'   => esc_html__( 'Add widgets here.', 'rt-health' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
			) );
			// Register new EDD Archive Sidebar widget area
			register_sidebar( array(
				'name'          => esc_html__( 'EDD Archive Sidebar', 'rt-health' ),
				'id'            => 'edd-archive-sidebar',
				'description'   => esc_html__( 'Add widgets here.', 'rt-health' ),
				'before_widget' => '<section id="%1$s" class="widget %2$s">',
				'after_widget'  => '</section>',
				'before_title'  => '<h2 class="widget-title">',
				'after_title'   => '</h2>',
			) );			
		}	

		/**
		 * Display EDD sidebar.
		 *
		 * @since 1.0.0
		 */
		public static function display_edd_sidebar( $sidebar ) {

			$is_edd_page                = rt_health_is_edd_page();
			$is_edd_single_product_page = rt_health_is_edd_single_product_page();

			if ( $is_edd_page && ! $is_edd_single_product_page ) {
				$sidebar = 'edd-archive-sidebar';
			} elseif ( $is_edd_single_product_page ) {
				$sidebar = 'edd-sidebar';
			}

			return $sidebar;

		}			

	}

endif;
RT_Health_Edd::get_instance();	
