<?php
/**
 * Custom theme functions.
 *
 * This file contains hook functions attached to theme hooks.
 *
 * @package RT_Health
 */

if ( ! function_exists( 'rt_health_header' ) ) :
	/**
	 * Header Section
 	 *
	 * @since 1.0.0
	 */
	function rt_health_header() {
	?>
    <!-- header starting from here -->
    <div class="hgroup-wrap">
        <div class="container">
            <section class="site-branding">
                <?php $site_identity  = rt_health_get_option( 'site_identity' );
                if ( in_array( $site_identity, array( 'logo-only', 'logo-text','logo-title' ) )  ) { ?>
                    <div class="site-logo">
                        <?php the_custom_logo(); ?> 
                    </div>
                <?php } ?>

                <?php if ( in_array( $site_identity, array( 'title-text', 'title-only', 'logo-text','logo-title' ) ) ) : ?>
                    <?php
                    if( in_array( $site_identity, array( 'title-text', 'title-only','logo-title' ) )  ) {
                        if ( is_front_page() && is_home() ) : ?>
                            <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                        <?php else : ?>
                            <p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                        <?php
                        endif;
                    } 
                    if ( in_array( $site_identity, array( 'title-text', 'logo-text' ) ) ) {
                        $description = get_bloginfo( 'description', 'display' );
                        if ( $description || is_customize_preview() ) : ?>
                            <p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
                        <?php
                        endif; 
                    }?>
                <?php endif; ?>
            </section><!-- .site-branding --> 
            <!-- site branding ends here -->
            <span class="header-info-responsive"></span>
            <div class="header-appoint-wrap">
                <?php $address_secton = rt_health_get_option( 'address_secton' ); 
                $address_secton = json_decode( $address_secton );
                $enable_header_address = rt_health_get_option( 'enable_header_address' ); 
                if ( true == $enable_header_address ): ?>
                    <div class="header-info">
                        <ul>
                            <?php foreach ($address_secton as $value ) {
                                $enable_header_icon = $value->enable_header_icon;
                                $header_icon        = $value->header_icon;
                                $header_address     = $value->header_address;
                                $header_url         = $value->header_url;
                                $header_desc        = $value->header_desc;
                            ?>
                                <li>
                                    <?php if ( !empty( $header_icon ) && 'yes' == $enable_header_icon ): ?>
                                        <span class="font-icon">
                                            <i class="<?php echo esc_attr( $header_icon );?>" aria-hidden="true"></i>
                                        </span>
                                    <?php endif; ?>
                                    <?php if( !empty( $header_url ) ) { ?>
                                        <p>
                                            <a href="<?php esc_url( $header_url );?>"><?php echo esc_html( $header_address);?></a>
                                            <?php if( !empty( $header_desc ) ) :
                                                    echo esc_html( $header_desc);
                                                endif; ?>
                                        </p>
                                    <?php } else{ ?>
                                        <p>
                                            <span><?php echo esc_html( $header_address);?></span><br>
                                            <?php if( !empty( $header_desc ) ) :
                                                echo esc_html( $header_desc);
                                            endif; ?>                                                    
                                        </p>
                                    <?php } ?>
                                </li>
                            <?php } ?>
                        </ul>
                    </div>
                <?php endif; ?>
                <?php 
                    $enable_header_button  = rt_health_get_option( 'enable_header_button' ); 
                    $button_text  = rt_health_get_option( 'button_text' ); 
                    $button_content  = rt_health_get_option( 'button_content' ); 
                    $button_url  = rt_health_get_option( 'button_url' ); 
                    $intro_page  = rt_health_get_option( 'intro_page' ); 

                    if ( true == $enable_header_button ): ?>
                        <div class="header-appointment-section">
                            <?php if ( 'url' == $button_content) { ?>
                                <a href="<?php echo esc_url( $button_url );?>"><?php echo esc_html( $button_text ); ?></a>
                            <?php } else{ ?>
                                <a class="header-appointment" href="#"><?php echo esc_html( $button_text ); ?></a>
                                <div class="appointment-dialog">
                                    <span class="appointmentclose"></span>
                                    <?php $args = array (                                   
                                        'page_id'           => absint($intro_page ),
                                        'post_status'       => 'publish',
                                        'post_type'         => 'page',
                                    );
                                    $loop = new WP_Query($args); 
                                    if ( $loop->have_posts() ) :
                                        while ($loop->have_posts()) : $loop->the_post();
                                            get_template_part( 'template-parts/content', 'page' );

                                        endwhile; // End of the loop.
                                        wp_reset_postdata();
                                    endif;
                                    ?>                                
                                </div>
                            <?php } ?>

                        </div>
                    <?php endif; ?>
            </div>
        </div>

        <div id="navbar" class="navbar">
            <!-- navbar starting from here -->
            <div class="container">
                <?php $enable_menu  = rt_health_get_option( 'enable_menu' );
                if ( true == $enable_menu ): ?>
                    <nav id="site-navigation" class="navigation main-navigation">
                        <div class="menu-content-wrapper">
    		                <?php
    		                wp_nav_menu( array(
    		                    'theme_location'    => 'menu-1',
    		                    'container_class'   => 'menu-top-menu-container',
    		                    'fallback_cb'       => 'rt_health_primary_navigation_fallback' ,
    		                ) );
    		                ?>                            	
                        </div>
                    </nav>
                <?php endif; ?>
                <!-- #site-navigation -->

                <?php $enable_search  = rt_health_get_option( 'enable_search' );
                if ( true == $enable_search ): ?>
                    <div id="left-search" class="search-container">
                        <div class="search-toggle">
                            <i class="fa"></i>
                        </div>
                        <div class="search-section">
                            <?php get_search_form();?>
                        </div>
                    </div>
                <?php endif; ?>

                <?php $enable_social_menu  = rt_health_get_option( 'enable_social_menu' );
                $icon_secton = rt_health_get_option( 'icon_secton' ); 
                $icon_secton = json_decode( $icon_secton );
                if ( true == $enable_social_menu && !empty( $icon_secton ) ): ?>
                    <div class="thumb-icon">
                        <a href="#" target="_self"><i class="fa fa-thumbs-o-up"></i></a>
                        <div class="block-social-icons social-links">
                            <ul>
                                <?php foreach ($icon_secton as $value ) {
                                    $icon_url = $value->icon_url;
                                    echo '<li><a href= "'.esc_url( $icon_url ).'"></a></li>';
                                } ?>
                            </ul>
                        </div>
                    </div>
                <?php endif; ?>

                <?php $enable_woo_cart  = rt_health_get_option( 'enable_woo_cart' );
                if ( true == $enable_woo_cart && rt_health_is_woocommerce_active() ): ?>
                    <div class="header-cart-views">
                        <i class="fas fa fa-shopping-cart"></i>
                        <span class="cart-quantity">
                            <?php echo wp_kses_data( WC()->cart->get_cart_contents_count() );?>
                        </span>
                        <div class="widget widget_shopping_cart_wrap">
                            <div class="mini_cart_inner">
                                <?php the_widget( 'WC_Widget_Cart', '' ); ?>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>
            </div>
        </div>
        <!-- navbar ends here -->
    </div>		
    <?php }
endif;
add_action( 'rt_health_action_header', 'rt_health_header', 10 );

if ( !function_exists( 'rt_health_top_footer') ):
    /**
     * Header Section
     *
     * @@since 1.0.0
    */
    function rt_health_top_footer(){
    ?>  
    <?php if ( is_active_sidebar( 'footer-1' ) || is_active_sidebar( 'footer-2' ) || is_active_sidebar( 'footer-3' )) : ?>    
        <div class="footer-info-section">
            <div class="map-section">  
                <?php dynamic_sidebar( 'footer-1' );  ?> 
            </div>

            <?php if ( is_active_sidebar( 'footer-2' ) ): ?>            
                <div class="widget-area info-wrap mCustomScrollbar">
                    <?php dynamic_sidebar( 'footer-2' ); ?>
                </div>           
            <?php endif; ?>             
            <?php if ( is_active_sidebar( 'footer-3' ) ): ?>
                <div class="subscription_field"> 
                    <div class="container mCustomScrollbar">
                        <div class="subscription-padding">
                            <?php dynamic_sidebar( 'footer-3' ); ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>           
        </div>
    <?php endif; 
    }
endif;
add_action( 'rt_health_action_footer', 'rt_health_top_footer', 10 );

if ( !function_exists( 'rt_health_footer') ):
    /**
     * Header Section
     *
     * @since 1.0.0
    */
    function rt_health_footer(){
    ?>  
    <div class="footer-bottom">
        <div class="container">
            <?php if ( has_nav_menu( 'footer-menu' ) ): ?>
                <div class="footer-menu">
                    <?php 
                    wp_nav_menu( array(
                        'theme_location' => 'footer-menu',
                        'depth'          => 1,
                        'fallback_cb'    => false,
                    ) );
                    ?>
                </div>
            <?php endif; ?>
                <?php $copyright_footer = rt_health_get_option( 'copyright_text' );
                // Powered by content.
                $powered_by_text = rt_health_get_option( 'poweredby_text' ); 
                if ( !empty( $copyright_footer ) || !empty( $powered_by_text ) ) : ?>             
                    <div class="copyright-part">
                        <span><?php echo wp_kses_post($powered_by_text);?></span>&nbsp;<span><?php echo wp_kses_data( $copyright_footer ); ?></span>
                    </div>
                <?php endif; ?>
        </div>
    </div>
    <?php $enable_scrollto_top = rt_health_get_option( 'enable_scrollto_top' );  
    if ( true == $enable_scrollto_top ): ?>
        <div class="back-to-top">
            <a href="#masthead" title="Go to Top" class="fa-angle-up"></a>
        </div>    
    <?php endif; 
    }
endif;
add_action( 'rt_health_action_footer', 'rt_health_footer', 15 );

if ( ! function_exists( 'rt_health_sidebar_layout' ) ) :

    /**
     * Add sidebar.
     *
     * @since 1.0.0
     */
    function rt_health_sidebar_layout() {

        // Sidebar Layout
        global $post;
        $sidebar_layout = rt_health_get_option( 'sidebar_layout' ); 
        $sidebar_layout = apply_filters( 'rt_health_sidebar_global_layout', $sidebar_layout );  
        
        // Check if single.
        if ( $post  && is_single() || is_page() ) {
            $sidebar_post_options = get_post_meta( $post->ID, 'sidebar_options', true );
            if ( isset( $sidebar_post_options ) && ! empty( $sidebar_post_options ) ) {
                if ( 'customizer_setting' == $sidebar_post_options ){
                    $sidebar_layout = rt_health_get_option( 'sidebar_layout' );
                } else{
                    $sidebar_layout = $sidebar_post_options;
                }
                
            }
        }

        // Include primary sidebar.
        if ( 'no_sidebar' !== $sidebar_layout ) {
            if ( rt_health_is_woocommerce_active() ){
                if ( is_shop() ){
                    get_sidebar( 'shop' );
                } else{
                    get_sidebar();
                }
            } else{
                get_sidebar();
            }
        }

    }

endif;

add_action( 'rt_health_action_sidebar_layout', 'rt_health_sidebar_layout' );

if ( ! function_exists( 'rt_health_title' ) ) :

    /**
     * Add Title.
     *
     * @since 1.0.0
     */
    function rt_health_title() {
        global $post;
        $title_options = get_post_meta( $post->ID, 'enable_title', true );
        if ( isset( $title_options ) && ! empty( $title_options ) ) {
            if( true == $title_options ){
                echo '<header class="entry-header"><h3 class="entry-title">';
                    the_title();
                echo "</h3></header>";
            }
        }

    }

endif;

add_action( 'rt_health_action_title', 'rt_health_title' );

if ( ! function_exists( 'rt_health_post_thumbnail' ) ) :

    /**
     * Add Feature Image.
     *
     * @since 1.0.0
     */
    function rt_health_post_thumbnail() {
        global $post;
        $image_options = get_post_meta( $post->ID, 'enable_feature_image', true );
        if ( isset( $image_options ) && ! empty( $image_options ) ) {
            if( true == $image_options ){
                echo '<div class="post-thumbnail"><figure class="featured-image">';
                    the_post_thumbnail();
                echo "</figure></div>";
            }
        }

    }

endif;

add_action( 'rt_health_action_image', 'rt_health_post_thumbnail' );

if ( ! function_exists( 'rt_health_post_comment' ) ) :

    /**
     * Enable/Disable Comment Section
     *
     * @since 1.0.0
     */
    function rt_health_post_comment() {
        global $post;
        $enable_comment = get_post_meta( $post->ID, 'enable_comment', true );
        if ( isset( $enable_comment ) && ! empty( $enable_comment ) ) {
            if( true == $enable_comment ){
                
                // If comments are open or we have at least one comment, load up the comment template.
                if ( comments_open() || get_comments_number() ) :
                    comments_template();
                endif;
            }
        }

    }

endif;

add_action( 'rt_health_action_comment', 'rt_health_post_comment' );

if ( ! function_exists( 'rt_health_404_page_content' ) ) :
    /**
     * 404 page content
     *
     * @since 1.4.5
     */
    function rt_health_404_page_content() {
        ?>
        <section class="error-404 not-found" style="background-image:url(<?php echo get_template_directory_uri();?>/assets/img/404.png); background-size: cover; background-repeat: no-repeat; background-attachment: fixed">
            <div class="container">
                <div class="style-404">
                    <span class="numbers"><?php echo absint(4); ?></span>
                    <span class="image-wrap">
                        <img src="<?php echo get_template_directory_uri();?>/assets/img/404-error.png" alt="">
                    </span>
                    <span class="numbers"><?php echo absint(4); ?></span>
                </div>
                <header class="entry-header">
                    <h2 class="entry-title"><?php esc_html_e( 'Page not found.', 'rt-health' ); ?></h2>
                </header>
                <a class="load-button" href="<?php echo esc_url( home_url() ); ?>"><span></span><?php esc_html_e( 'Back to Home.', 'rt-health' ); ?></a>
            </div>
        </section>             
        <?php
    }
endif;
add_action( 'rt_health_action_404_page', 'rt_health_404_page_content' );