<?php
/**
 * Default theme options.
 *
 * @package RT_Health
 */

if ( ! function_exists( 'rt_health_get_default_theme_options' ) ) :

	/**
	 * Get default theme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
function rt_health_get_default_theme_options() {

	$defaults = array();

	$defaults['site_identity']					= 'title-text';
	$defaults['enable_header_address']			= false;

	$defaults['enable_breadcrumb']				= true;
	$defaults['header_image']					= 'header-image';

	$defaults['enable_header_button']			= true;
	$defaults['button_text']					= esc_html__( 'Appointment', 'rt-health' );
	$defaults['button_content']					= 'url';
	$defaults['button_url']						= '';
	$defaults['intro_page']						= 0;

	$defaults['enable_menu']					= true;
	$defaults['enable_search']					= true;
	$defaults['enable_social_menu']				= true;
	$defaults['enable_woo_cart']				= true;

	// Blog Setting
	$defaults['enable_post_meta']				= true;
	$defaults['view_details']					= esc_html__( 'View Details', 'rt-health' );

	// General Setting
	$defaults['sidebar_layout']					= 'right_sidebar';
	$defaults['pagination_layout']				= 'default';


	// Footer Section 
	$defaults['copyright_text']					= '';
	$defaults['poweredby_text']					= sprintf( __( 'Theme of %s', 'rt-health' ), '<a target="_blank" rel="designer" href="https://rigorousthemes.com/">Rigorous Themes.</a>' );
	$defaults['enable_scrollto_top']			= true;

	// Pass through filter.
	$defaults = apply_filters( 'rt_health_filter_default_theme_options', $defaults );
	return $defaults;
}

endif;

/**
*  Get theme options
*/
if ( ! function_exists( 'rt_health_get_option' ) ) :

	/**
	 * Get theme option
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Option key.
	 * @return mixed Option value.
	 */
	function rt_health_get_option( $key ) {

		$default_options = rt_health_get_default_theme_options();

		if ( empty( $key ) ) {
			return;
		}

		$theme_options = (array)get_theme_mod( 'theme_options' );
		$theme_options = wp_parse_args( $theme_options, $default_options );

		$value = null;

		if ( isset( $theme_options[ $key ] ) ) {
			$value = $theme_options[ $key ];
		}

		return $value;

	}

endif;